@@ -12,11 +12,11 @@ pub fn e_num(item: TokenStream) -> TokenStream {
     let impl_ident = &ast.ident;
 
     quote! {
-        impl From<usize> for #impl_ident {
-            fn from(self) -> usize {
-                self as usize
-            }
+    impl From<#impl_ident> for usize {
+        fn from(opt: #impl_ident) -> usize {
+            opt as usize
         }
     }
+    }
     .into()
 }
